@@ -7,8 +7,10 @@ extends qw/Moose::Meta::Method/;
 sub wrap_with_signature {
   my ($class,$signature,$coderef) = @_;
 
-  confess "Signature must be a MooseX::Meta::Signature"
-    unless blessed $signature && $signature->isa ('MooseX::Meta::Signature');
+  confess "Signature must do MooseX::Meta::Signature"
+    unless blessed $signature &&
+           $signature->can ('does') &&
+           $signature->does ('MooseX::Meta::Signature');
 
   my $self = $class->wrap ($coderef);
 
